@@ -1,9 +1,7 @@
 .onAttach <- function(libname, pkgname) {
   packageStartupMessage("Data: (c) OpenStreetMap contributors, ODbL 1.0 - http://www.openstreetmap.org/copyright")
   packageStartupMessage("Routing: OSRM - http://project-osrm.org/")
-  packageStartupMessage(paste0("sp support will be dropped in the next major release, ",
-                               "please use sf objects instead."))
-  
+
   # options(osrm.server = "http://0.0.0.0:5000/", osrm.profile = "driving")
 }
 
